<?php
/** Eastern Canadian (Latin script) (inuktitut)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$messages = array(
# User preference toggles
'tog-rememberpassword' => 'Iqtuu uikipitia atiq qakugiq atuinnasivuq uvalumaq qaritaujaq (for a maximum of $1 {{PLURAL:$1|day|days}})',

# Dates
'sunday'       => 'sanattaili',
'monday'       => 'naggajaq',
'wednesday'    => 'pingajua',
'friday'       => 'pagaitaak',
'sun'          => 'sana',
'mon'          => 'nag',
'wed'          => 'pinga',
'january'      => 'januari',
'february'     => 'vipuari',
'march'        => 'maarsi',
'april'        => 'aipuril',
'may_long'     => 'mai',
'june'         => 'juni',
'july'         => 'julai',
'august'       => 'augus',
'october'      => 'uktupuri',
'november'     => 'nuvimpuri',
'december'     => 'tisimpuri',
'january-gen'  => 'januari',
'february-gen' => 'vipuari',
'march-gen'    => 'maarsi',
'april-gen'    => 'aipuril',
'may-gen'      => 'mai',
'june-gen'     => 'juni',
'july-gen'     => 'julai',
'august-gen'   => 'augus',
'october-gen'  => 'uktupuri',
'november-gen' => 'nuvimpuri',
'december-gen' => 'tisimpuri',
'apr'          => 'aipu',
'may'          => 'mai',
'aug'          => 'augu',
'nov'          => 'nuvi',

'about'         => 'miksaani',
'article'       => 'ilulik mappitaq',
'newwindow'     => '(uittuq qarasaujaq ikiaq pigivuq igalaaq)',
'cancel'        => 'iniqtipaa',
'moredotdotdot' => 'pilluarivaa...',
'mypage'        => 'ami mappitaq',
'mytalk'        => 'atlarqutikka',
'navigation'    => 'mianirivaa',
'and'           => '&#32;amma',

# Cologne Blue skin
'qbspecialpages' => 'piji mappitaq',

# Vector skin
'vector-view-edit' => 'Suqusiqpaa',

'help'              => 'qajalippaa',
'search'            => 'ivaaqpuq',
'searchbutton'      => 'ivaaqpuq',
'go'                => 'aivuq',
'searcharticle'     => 'aivuk',
'history_short'     => 'mappitaq kingunittinni',
'edit'              => 'Suqusiqpaa',
'editthispage'      => 'suqusiqpaa mappitaq',
'delete'            => 'nipaqtipaa',
'protect'           => 'sapummivaa',
'unprotect'         => 'iq sapummivaa',
'unprotectthispage' => 'iq sapummivaa mappitaq',
'newpage'           => 'pigivuk mappitaq',
'specialpage'       => 'piji mappitaq',
'articlepage'       => 'ilulik mappitaq uvva',
'talk'              => 'uqalimajuq',
'toolbox'           => 'sanarqutiqauti',
'otherlanguages'    => 'killumut uiki',
'redirectedfrom'    => '(qaningani kamagijaq aasit nakit $1)',
'redirectpagesub'   => 'aningani kamagijaq aasit nakit mappitaq',
'jumptonavigation'  => 'mianirivaa',
'jumptosearch'      => 'ivaaqpuq',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'miksaani {{SITENAME}}',
'aboutpage'            => 'Project:miksaani',
'currentevents'        => 'pigivuq piusiq',
'currentevents-url'    => 'Project:pigivuq piusiq',
'edithelp'             => 'ikurripaa suqusiqpaa',
'edithelppage'         => 'Help:suqusiqpaa',
'mainpage'             => 'amiq',
'mainpage-description' => 'amiq',
'portal'               => 'qaggiq',
'portal-url'           => 'Project:qaggiq',
'privacy'              => 'namminiq pilirivviqauqtunut aulataujut atuagaq, pinasuarniq',
'privacypage'          => 'Project:namminiq pilirivviqauqtunut aulataujut atuagaq, pinasuarniq',

'youhavenewmessages'  => 'ilissu pigivaa $1 ($2).',
'newmessageslink'     => 'pigivuk kiggapaa',
'newmessagesdifflink' => 'annitujuq asiaNngutuq',
'editsection'         => 'suqusiqpaa',
'editold'             => 'suqusiqpaa',
'editlink'            => 'suqusiqpaa',
'editsectionhint'     => 'suqusiqpaa ilangiutititsiguti: $1',
'site-rss-feed'       => '$1 rss mianirivaa',
'site-atom-feed'      => '$1 atum mianirivaa',
'page-rss-feed'       => '"$1" rss mianirivaa',
'page-atom-feed'      => '"$1" atum mianirivaa',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'mappitaq',
'nstab-user'      => 'inuk mappitaq',
'nstab-special'   => 'piji',
'nstab-project'   => 'piliriaksait pivalliajjutiksanut miqitaq',
'nstab-mediawiki' => 'kiggapaa',
'nstab-template'  => 'mianirivaa-qijuqut',
'nstab-category'  => 'nuapput',

# General errors
'badtitle'         => 'ajuqtuq atiq',
'editinginterface' => "'''iniqtiruti—''' aaha suqusiqpaa iqiak mappitaq atuinnasivuq iijatsaq qarasaujaq taqsaliqpaa ikiaq aqittuq qaritaujaup titirarvinga. asiaNngutuq ikiaq mappitaq inuktitut uikipitia allanguqtuaq nakimaqpuq qatannguti.",

# Login and logout pages
'welcomecreation'    => "== ariunngaipaa, $1! ==
pigivuq qatannguti uikipitia kiinaujaqutiqarvik isuillingaitjapaa. iqtuu suqusiqpa{{SITENAME}} inniatuq—«''nipi ami''»",
'yourname'           => 'uikipitia atiq',
'yourpassword'       => 'uikipitia palanngasauti',
'yourpasswordagain'  => 'tamatumaniiqpaa iksigaqtuq uikipitia palanngasauti',
'remembermypassword' => 'iqtuu uikipitia atiq qakakuq atuinnasivuq uvalumajuq qaritaujaq (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login'              => 'akunnapuq',
'loginprompt'        => 'pigialik imatuaq qaritaujaq quukiis (Cookies) pirqaati akunnapuq {{SITENAME}}.',
'userlogin'          => 'akunnapuq / pirqaapaa kiinaijakkuvingmi tuqkuqsivik',
'logout'             => 'anivvik',
'userlogout'         => 'anivvik',
'nologin'            => "ajuinnaaq inuquti? '''$1'''.",
'nologinlink'        => 'pirqaapaa kiinaujakkuvingmi tuqkuqsivik',
'mailmypassword'     => 'qillutuq uikipitia palanngasauti kigutiup sitiniqpaanga',

# Edit page toolbar
'bold_sample' => 'ijjujug taqsaliqpaa',
'bold_tip'    => 'ijjujug taqsaliqpaa',

# Edit pages
'summary'         => 'suvit:',
'minoredit'       => 'ukiukiluaq asianngutuq',
'watchthis'       => 'uvva',
'savearticle'     => 'uqausillaringgita titiraqtauninggil',
'preview'         => 'uvva qangasaanguliqtuq',
'showpreview'     => 'surkuqpaa alakkautivuq sivuliqpaa uqaasillarigita titiraqtauningigit',
'showdiff'        => 'alakkatippaa asianngutuq',
'summary-preview' => 'suvit preview:',
'blockedtitle'    => 'aaqqiksuiji uminngasisijuq',
'loginreqlink'    => 'akunnapuq',
'newarticle'      => '(pigivuk)',
'editingsection'  => 'suqusiqpaa $1 (ilangiutititsiguti)',
'editingcomment'  => 'suqusiqpaa $1 (ujjirijaq)',
'editconflict'    => 'suqusiqpaa akaunngiliurutiniq: $1',

# History pages
'currentrev'          => 'maanna titiraqtaugiarngarut',
'previousrevision'    => '←utuqaq titiraqtaugiarngarut',
'nextrevision'        => 'pilluarivaa pigivuk revision titiraqtaugiarngarut→',
'currentrevisionlink' => 'maanna titiraqtaugiarngarut',
'next'                => 'tagga',

# Revision feed
'history-feed-title'       => 'titiraqtaugiarngarut mappitaq kingunittinni',
'history-feed-description' => 'titiraqtaugiarngarut mappitaq kingunittinni ikiaq uiki',

# Diffs
'history-title' => 'titiraqtaugiarngarut mappitaq kingunittinni "$1"',
'difference'    => '(asiaNngutuq mappitaq akunninganni titiraqtaugiarngarut)',
'lineno'        => 'tukiqsiq $1:',
'editundo'      => 'ipiutjaapaa',
'diff-multi'    => '({{PLURAL:$1|atausiq kimmiuvuq titiraqtaugiarngarut|$1 kimmiuvuq titiraqtaugiarngarut}} ajuqtuq uvva.)',

# Search results
'nextn'       => 'tagga {{PLURAL:$1|$1}}',
'powersearch' => 'ivaaqpuq',

# Preferences page
'mypreferences'     => 'mi pikkumaniqpaaq',
'prefs-rc'          => 'pigivuq asianngutuq',
'searchresultshead' => 'ivaaqpuq',
'youremail'         => 'kigutiup sitiniqpaanga:',
'username'          => 'uikipitia atiq:',
'yourrealname'      => 'inullarik atiq:',
'email'             => 'kigutiup sitiniqpaanga',
'prefs-help-email'  => 'kigutiup sitiniqpaanga (pikkallavuq) — qakugu nalunanngilaq ilissi pijungnaqtuq pigivaa kanngunaqtuq aajiiqatiginggiq',

# User rights
'editinguser' => "suqusiqpaa qatannguti '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",

# Recent changes
'recentchanges' => 'pigivuq asianngutuq',

# Recent changes linked
'recentchangeslinked'          => 'asiaNngutuq mitsaasijuq',
'recentchangeslinked-feed'     => 'asiaNngutuq mitsaasijuq',
'recentchangeslinked-toolbox'  => 'asiaNngutuq mitsaasijuq',
'recentchangeslinked-noresult' => '0 asiaNngutuq itsivimmiusiqpaa mappitaq takuvallatuq sulluk tamatumani tumiku',

# Upload
'upload'            => 'mappipaa nalinaijatit',
'uploadbtn'         => 'mappipaa nalunaijautit',
'filedesc'          => 'piliriaksat pivigjuanguningit',
'fileuploadsummary' => 'suvit:',
'watchthisupload'   => 'uvva',

# List redirects
'listredirects' => 'nipi qaningani kamagijaq aasit nakit',

# Random page
'randompage' => 'nakituinnaq qaujisarniq mappitaq',

# Random redirect
'randomredirect' => 'nakituinnaq qaujisarniq qaningani kamagijaq aasit nakit',

# Statistics
'statistics'              => 'kisitsisillgurlugitpasissitissat',
'statistics-header-users' => 'qatannguti kisitsisillgurlugitpasissitissat',

'doubleredirects' => 'tapirqilik qaningani kamagijaq aasit nakit',

'brokenredirects'        => 'napivaa qaningani kamagijaq aasit nakit',
'brokenredirects-edit'   => 'suqusiqpaa',
'brokenredirects-delete' => 'nipaqtipaa',

# Miscellaneous special pages
'listusers'         => 'qatannguti nipi',
'newpages-username' => 'uikipitia atiq:',
'ancientpages'      => 'utuqaq ittusaq mappitaq',
'move'              => 'uajuq',

# Book sources
'booksources-go' => 'aivuq',

# Special:AllPages
'allpages'       => 'sunamittuq mappitaq',
'nextpage'       => 'tagga mappitaq ($1)',
'allpagesprev'   => 'tunullipaaq',
'allpagesnext'   => 'tagga',
'allpagessubmit' => 'aivuk',

# Special:Categories
'categories' => 'nuapput',

# E-mail user
'emailfrom'    => 'nakit',
'emailmessage' => 'kiggapaa',
'emailsend'    => 'qiutsavigivaa',

# Watchlist
'watchlist'     => 'uvva mappitaq',
'mywatchlist'   => 'nipi ami',
'watch'         => 'uvva',
'watchthispage' => 'uvva',
'unwatch'       => 'iq uvva',

'enotif_impersonal_salutation' => '{{SITENAME}} qatannguti',
'created'                      => 'mappitaq anivuq',

# Delete
'dellogpage'  => 'nipaq nipi',
'deletionlog' => 'nipaq nipi',

# Protect
'prot_1movedto2'      => '[[$1]] surramajuq [[$2]]',
'protect-legend'      => 'patimmivaa sapummivaa',
'protect-level-sysop' => 'sirlak titiraqsimajunik tuqquqtiriji',

# Restrictions (nouns)
'restriction-edit' => 'Suqusiqpaa',
'restriction-move' => 'uajuq',

# Undelete
'undelete-search-submit' => 'ivaaqpuq',

# Namespace form on various pages
'blanknamespace' => '(amiq)',

# Contributions
'mycontris' => 'taliaq',

'sp-contributions-submit' => 'ivaaqpuq',

# What links here
'whatlinkshere' => 'uqsiq maungu',
'isredirect'    => 'tapitariik uqsaq mappitaq',

# Block/unblock
'blockip'                  => 'iq aaqqiksuiji',
'badipaddress'             => 'illituq qarisaujakkut titiraqsimajut maligatigut angirutausimajuq unikkaarijaqarniq',
'blockipsuccesssub'        => 'uminngasisijuq naajuq',
'ipblocklist-submit'       => 'ivaaqpuq',
'anononlyblock'            => 'sirlak ilisarnanngitittuq',
'blocklink'                => 'iq',
'contribslink'             => 'qatannguti suqusiqpaa',
'blocklogpage'             => 'uminngasisijuq/iq titiqqaqutit tuqquqsimajait',
'block-log-flags-anononly' => 'ilisarnanngitittuq aaqqiksuiji kisiani',
'block-log-flags-nocreate' => 'kiinaujaqarvik inuirutivaa iniqtipaa pigivuq',
'block-log-flags-noemail'  => 'kigutiup sitiniqpaanga uminngasisijuq',

# Move page
'move-page-legend' => 'uajuq mappitaq',
'movearticle'      => 'uajuq mappitaq',
'movedto'          => 'uajuq',
'1movedto2'        => '[[$1]] surramajuq [[$2]]',
'1movedto2_redir'  => '[[$1]] surramajuq [[$2]] misippaa qaningani kamagijaq aasit nakit',
'movelogpage'      => 'uajuq nipi',
'delete_and_move'  => 'nipaqtipaa amma uajuq',

# Namespace 8 related
'allmessagesname' => 'atiq',

# Import log
'import-logentry-upload-detail'    => '$1 {{PLURAL:$1|titiraqtaugiarngarut|titiraqtaugiarngarut}}',
'import-logentry-interwiki-detail' => '$1 {{PLURAL:$1|titiraqtaugiarngarut|titiraqtaugiarngarut}} ikiaq $2',

# Tooltip help for the actions
'tooltip-ca-protect'              => 'sapummivaa mappitaq',
'tooltip-search'                  => 'ivaaqpuq {{SITENAME}}',
'tooltip-minoredit'               => 'tuapaq asiaNngutuq',
'tooltip-diff'                    => 'surrapaa qatannguti',
'tooltip-compareselectedversions' => 'uvva asiaNngutuq mappitaq akunninganni marruuk titiraqtaugiarngarut',

# Attribution
'anonymous' => 'ilisarnanngitittuq qatannguti nakit {{SITENAME}}',

# Math errors
'math_unknown_error'    => 'tusaumajaunngituq tammanaqtuq',
'math_unknown_function' => 'tusaumajaunngituq iliurniq',

# Image deletion
'deletedrevision' => 'nipaq utuqaq titiraqtaugiarngarut $1',

# Browsing diffs
'previousdiff' => '← tunullipaaq asiaNngutuq',
'nextdiff'     => 'tagga asiaNngutuq mappitaq →',

# Special:NewFiles
'ilsubmit' => 'ivaaqpuq',
'bydate'   => 'pitaaruttuq inuulirvik',

# EXIF tags
'exif-imagelength'         => 'qutsingniq',
'exif-imagedescription'    => 'inunnguaq atiq',
'exif-colorspace'          => 'minguarutimitiqpaa',
'exif-datetimeoriginal'    => 'qatsipaa amma tikiuti sarqipaa isuillingaitjapaa',
'exif-datetimedigitized'   => 'qatsipaa amma tikiuti sarqipaa qarasaujaq',
'exif-exposuretime-format' => '$1 aippaq ($2)',
'exif-brightnessvalue'     => 'qaummapaa akkiutaq',

# 'all' in various places, this might be different for inflected languages
'monthsall' => 'sunamittuq',

# action=purge
'confirm_purge_button' => 'akaujuq',

# Multipage image navigation
'imgmultipageprev' => '← tunullipaaq mappitaq',
'imgmultipagenext' => 'tagga mappitaq →',
'imgmultigo'       => 'aivuq!',

# Table pager
'table_pager_limit_submit' => 'aivuk',

# Auto-summaries
'autoredircomment' => 'qaningani kamagijaq aasit nakit [[$1]]',
'autosumm-new'     => 'pigivuq mappitaq: $1',

# Special:SpecialPages
'specialpages' => 'piji mappitaq',

# Special:Tags
'tags-edit' => 'suqusiqpaa',

);
